@@ -21,7 +21,9 @@ require 'extended/comment_node'
 require 'extended/custom_stream'
 require 'extended/custom_visitor'
 require 'extended/eof_node'
+require 'extended/feature_index'
 require 'extended/feature_node'
+require 'extended/feature_stream'
 require 'extended/gff3_in_stream'
 require 'extended/gff3_out_stream'
 require 'extended/gff3_visitor'
