@@ -1,8 +1,8 @@
 /*
-  Copyright (c) 2007-2010 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
+  Copyright (c) 2007-2012 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
   Copyright (c) 2007      Malte Mader <mader@zbh.uni-hamburg.de>
   Copyright (c) 2007      Christin Schaerfer <schaerfer@zbh.uni-hamburg.de>
-  Copyright (c) 2007-2010 Center for Bioinformatics, University of Hamburg
+  Copyright (c) 2007-2012 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -20,7 +20,7 @@
 #include "annotationsketch/canvas.h"
 #include "annotationsketch/canvas_cairo_file.h"
 #include "annotationsketch/diagram.h"
-#include "annotationsketch/feature_index_memory_api.h"
+#include "extended/feature_index_memory_api.h"
 #include "annotationsketch/line_breaker_captions.h"
 #include "annotationsketch/style.h"
 #include "annotationsketch/track.h"
@@ -32,7 +32,7 @@
 #include "core/msort.h"
 #include "core/log.h"
 #include "core/str.h"
-#include "core/thread.h"
+#include "core/thread_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
 #include "extended/feature_node.h"
@@ -178,7 +178,7 @@ static int get_caption_display_status(GtDiagram *d, const char *gft,
   {
     unsigned long threshold = GT_UNDEF_ULONG;
     double tmp = GT_UNDEF_DOUBLE;
-    status = gt_malloc(sizeof (bool*));
+    status = gt_malloc(sizeof (bool));
     *status = true;
     if (gt_style_get_bool(d->style, "format", "show_block_captions", status,
                           NULL, err) == GT_STYLE_QUERY_ERROR) {
@@ -591,9 +591,17 @@ static int process_node(GtDiagram *d, GtFeatureNode *node,
           }
         }
       } else {
-        if (add_to_current(d, node, parent, err) < 0) {
+        if (gt_feature_node_is_pseudo(parent)
+              && gt_feature_node_is_multi(node))
+        {
+          if (add_to_rep(d, node, parent, err) < 0) {
             return -1;
           }
+        } else {
+          if (add_to_current(d, node, parent, err) < 0) {
+            return -1;
+          }
+        }
       }
     } else {
       /* root nodes always get their own block */
