@@ -50,8 +50,6 @@ struct GtGraphicsCairo {
   double margin_x, margin_y, height, width;
   bool from_context;
   PangoLayout *layout;
-  PangoFontMap *fmap;
-  PangoContext *pcontext;
   PangoFontDescription *desc;
   int font_height;
 };
@@ -169,10 +167,7 @@ void gt_graphics_cairo_draw_text(GtGraphics *gg, double x, double y,
   pango_layout_set_text(g->layout, text, -1);
 
   /* get text extents */
-  pango_layout_line_get_pixel_extents(pango_layout_get_line_readonly(g->layout,
-                                                                     0),
-                                      &ink,
-                                      NULL);
+  pango_layout_get_pixel_extents(g->layout, &ink, NULL);
 
   if (gt_double_smaller_double(g->width, x+ink.width))
     return;
@@ -213,10 +208,7 @@ void gt_graphics_cairo_draw_text_centered(GtGraphics *gg, double x, double y,
   pango_layout_set_text(g->layout, text, -1);
 
   /* get text extents */
-  pango_layout_line_get_pixel_extents(pango_layout_get_line_readonly(g->layout,
-                                                                     0),
-                                      &ink,
-                                      NULL);
+  pango_layout_get_pixel_extents(g->layout, &ink, NULL);
 
   cairo_set_source_rgb(g->cr, 0, 0, 0);
   /* draw text w/ its center at the given coords */
@@ -234,10 +226,7 @@ void gt_graphics_cairo_draw_text_right(GtGraphics *gg, double x, double y,
   pango_layout_set_text(g->layout, text, -1);
 
   /* get text extents */
-  pango_layout_line_get_pixel_extents(pango_layout_get_line_readonly(g->layout,
-                                                                     0),
-                                      &ink,
-                                      NULL);
+  pango_layout_get_pixel_extents(g->layout, &ink, NULL);
 
   cairo_set_source_rgb(g->cr, 0, 0, 0);
   /* draw text w/ its right end at the given coords */
@@ -344,17 +333,14 @@ void gt_graphics_cairo_draw_vertical_line(GtGraphics *gg, double x, double y,
 
 double gt_graphics_cairo_get_text_width(GtGraphics *gg, const char* text)
 {
-  PangoLayoutLine *line;
   PangoRectangle rect;
   GtGraphicsCairo *g = gt_graphics_cairo_cast(gg);
   gt_assert(g && text && g->layout);
 
   pango_layout_set_text(g->layout, text, -1);
   /* get text extents */
-  gt_assert(pango_layout_get_line_count(g->layout) > 0);
-  line = pango_layout_get_line_readonly(g->layout, 0);
-  gt_assert(line);
-  pango_layout_line_get_pixel_extents(line, &rect, NULL);
+
+  pango_layout_get_pixel_extents(g->layout, &rect, NULL);
 
   gt_assert(gt_double_smaller_double(0, rect.width));
   return rect.width;
@@ -752,7 +738,6 @@ void gt_graphics_cairo_delete(GtGraphics *gg)
     cairo_surface_destroy(g->surf); /* reference counted */
   if (g->outbuf)
     gt_str_delete(g->outbuf);
-  g_object_unref(g->pcontext);
   g_object_unref(g->layout);
 }
 
@@ -802,9 +787,7 @@ GtGraphics* gt_graphics_cairo_new(GtGraphicsOutType type,
   g = gt_graphics_create(gt_graphics_cairo_class());
   gc = gt_graphics_cairo_cast(g);
   gt_graphics_cairo_initialize(g, type, width, height);
-  gc->fmap =  pango_cairo_font_map_get_default();
-  gc->pcontext = pango_font_map_create_context(gc->fmap);
-  gc->layout = pango_layout_new(gc->pcontext);
+  gc->layout = pango_cairo_create_layout(gc->cr);
   pango_layout_set_width(gc->layout, -1);
   gt_assert(gc->layout);
   snprintf(buf, 64, "Sans %d", TEXT_SIZE_DEFAULT);
@@ -828,9 +811,7 @@ GtGraphics* gt_graphics_cairo_new_from_context(cairo_t *context,
   gc->margin_x = gc->margin_y = 20;
   gc->from_context = true;
   gc->cr = context;
-  gc->fmap =  pango_cairo_font_map_new();
-  gc->pcontext = pango_font_map_create_context(gc->fmap);
-  gc->layout = pango_layout_new(gc->pcontext);
+  gc->layout = pango_cairo_create_layout(gc->cr);
   pango_layout_set_width(gc->layout, -1);
   gt_assert(gc->layout);
   snprintf(buf, 64, "Sans %d", TEXT_SIZE_DEFAULT);
