@@ -23,7 +23,7 @@
 #include "core/fileutils_api.h"
 #include "core/gtdatapath.h"
 #include "core/option_api.h"
-#include "core/outputfile.h"
+#include "core/output_file_api.h"
 #include "core/ma.h"
 #include "core/splitter.h"
 #include "core/undef_api.h"
@@ -32,6 +32,8 @@
 #include "core/warning_api.h"
 #include "extended/add_introns_stream_api.h"
 #include "extended/bed_in_stream.h"
+#include "extended/feature_index_memory_api.h"
+#include "extended/feature_stream_api.h"
 #include "extended/gff3_in_stream.h"
 #include "extended/gff3_out_stream_api.h"
 #include "extended/gtf_in_stream.h"
@@ -40,8 +42,6 @@
 #include "annotationsketch/canvas_api.h"
 #include "annotationsketch/canvas_cairo_file.h"
 #include "annotationsketch/diagram.h"
-#include "annotationsketch/feature_index_memory_api.h"
-#include "annotationsketch/feature_stream_api.h"
 #include "annotationsketch/gt_sketch.h"
 #include "annotationsketch/image_info.h"
 #include "annotationsketch/layout.h"
