@@ -26,12 +26,14 @@
 #include "core/alphabet.h"
 #include "core/chardef.h"
 #include "core/cstr_api.h"
+#include "core/ensure.h"
 #include "core/fileutils_api.h"
 #include "core/fa.h"
 #include "core/gtdatapath.h"
 #include "core/ma_api.h"
 #include "core/mathsupport.h"
 #include "core/str_array.h"
+#include "core/thread_api.h"
 #include "core/unused_api.h"
 #include "core/xansi_api.h"
 
@@ -50,6 +52,7 @@ struct GtAlphabet {
           symbolmap[GT_MAXALPHABETCHARACTER+1], /* mapping of the symbols */
           *mapdomain,                        /* list of characters mapped */
           *characters;                       /* array of characters to show */
+  GtMutex *refmutex;
   GtStr *alphadef;
 };
 
@@ -332,25 +335,31 @@ static void assign_dna_symbolmap(GtUchar *symbolmap)
   }
 }
 
-GtAlphabet *gt_alphabet_clone(const GtAlphabet *alphabet)
+GtAlphabet* gt_alphabet_clone(const GtAlphabet *alphabet)
 {
   unsigned int i;
   GtAlphabet *newalpha;
+  gt_assert(alphabet);
 
   newalpha = gt_malloc(sizeof *newalpha);
   newalpha->domainsize = alphabet->domainsize;
   newalpha->mapsize = alphabet->mapsize;
   newalpha->mappedwildcards = alphabet->mappedwildcards;
   newalpha->wildcardshow = alphabet->wildcardshow;
+  newalpha->bitspersymbol = alphabet->bitspersymbol;
+  newalpha->alphadef = gt_str_ref(alphabet->alphadef);
   newalpha->reference_count = 0;
+  newalpha->refmutex = gt_mutex_new();
   for (i=0; i<=(unsigned int) GT_MAXALPHABETCHARACTER; i++)
   {
     newalpha->symbolmap[i] = alphabet->symbolmap[i];
   }
+  newalpha->characters = gt_malloc(alphabet->mapsize * sizeof (GtUchar));
   for (i=0; i<newalpha->mapsize; i++)
   {
     newalpha->characters[i] = alphabet->characters[i];
   }
+  newalpha->mapdomain = gt_malloc(alphabet->domainsize * sizeof (GtUchar));
   for (i=0; i<newalpha->domainsize; i++)
   {
     newalpha->mapdomain[i] = alphabet->mapdomain[i];
@@ -361,10 +370,31 @@ GtAlphabet *gt_alphabet_clone(const GtAlphabet *alphabet)
 GtAlphabet* gt_alphabet_ref(GtAlphabet *alphabet)
 {
   gt_assert(alphabet);
+  gt_mutex_lock(alphabet->refmutex);
   alphabet->reference_count++;
+  gt_mutex_unlock(alphabet->refmutex);
   return alphabet;
 }
 
+bool gt_alphabet_equals(const GtAlphabet *a, const GtAlphabet *b)
+{
+  gt_assert(a && b);
+  if (a->domainsize != b->domainsize) return false;
+  if (a->mapsize != b->mapsize) return false;
+  if (a->mappedwildcards != b->mappedwildcards) return false;
+  if (a->wildcardshow != b->wildcardshow) return false;
+  if (memcmp(a->symbolmap, b->symbolmap,
+             GT_MAXALPHABETCHARACTER * sizeof (GtUchar)))
+    return false;
+  if (memcmp(a->characters, b->characters,
+             a->mapsize * sizeof (GtUchar)))
+    return false;
+  if (memcmp(a->mapdomain, b->mapdomain,
+             a->domainsize * sizeof (GtUchar)))
+    return false;
+  return true;
+}
+
 void gt_alphabet_add_mapping(GtAlphabet *alphabet, const char *characters)
 {
   size_t i, num_of_characters;
@@ -568,6 +598,7 @@ GtAlphabet* gt_alphabet_new_empty(void)
   a->mappedwildcards = 0;
   a->bitspersymbol = 0;
   a->reference_count = 0;
+  a->refmutex = gt_mutex_new();
   a->wildcardshow = (GtUchar) UNDEFCHAR;
   memset(a->symbolmap, (int) UNDEFCHAR, (size_t) GT_MAXALPHABETCHARACTER+1);
   a->mapdomain = NULL;
@@ -1029,29 +1060,41 @@ int gt_alphabet_to_file(const GtAlphabet *alphabet, const char *indexname,
 void gt_alphabet_delete(GtAlphabet *alphabet)
 {
   if (!alphabet) return;
+  gt_mutex_lock(alphabet->refmutex);
   if (alphabet->reference_count) {
     alphabet->reference_count--;
+    gt_mutex_unlock(alphabet->refmutex);
     return;
   }
+  gt_mutex_unlock(alphabet->refmutex);
   gt_free(alphabet->mapdomain);
   gt_free(alphabet->characters);
   if (alphabet->alphadef != NULL)
     gt_str_delete(alphabet->alphadef);
+  gt_mutex_delete(alphabet->refmutex);
   gt_free(alphabet);
 }
 
-/* int gt_alphabet_unit_test(GtError *err)
+int gt_alphabet_unit_test(GtError *err)
 {
   int had_err = 0;
-  GtAlphabet *a;
-  const char *alpha1 = "aA\ncC\ngG\ntTuU\nnsywrkvbdhmNSYWRKVBDHM",
-             *alpha2 = "";
-  unsigned long alpha1len,
-                alpha2len;
+  GtAlphabet *a, *b, *c;
   gt_error_check(err);
 
-  alpha1len = strlen(alpha1);
-  alpha2len = strlen(alpha2);
+  a = gt_alphabet_new_dna();
+  b = gt_alphabet_new_protein();
+  c = gt_alphabet_clone(a);
+
+  gt_ensure(had_err, gt_alphabet_equals(a, a));
+  gt_ensure(had_err, gt_alphabet_equals(b, b));
+  gt_ensure(had_err, gt_alphabet_equals(c, c));
+
+  gt_ensure(had_err, !gt_alphabet_equals(a, b));
+  gt_ensure(had_err, gt_alphabet_equals(a, c));
+
+  gt_alphabet_delete(a);
+  gt_alphabet_delete(b);
+  gt_alphabet_delete(c);
 
   return had_err;
-}*/
+}
