@@ -23,7 +23,7 @@
 #include "core/alphabet.h"
 #include "core/chardef.h"
 #include "core/codetype.h"
-#include "core/disc_distri.h"
+#include "core/disc_distri_api.h"
 #include "core/encseq_api.h"
 #include "core/encseq_access_type.h"
 #include "core/encseq_options.h"
@@ -56,6 +56,11 @@ GtEncseqEncoder* gt_encseq_encoder_new_from_options(GtEncseqOptions *opts,
 GtEncseqLoader* gt_encseq_loader_new_from_options(GtEncseqOptions *opts,
                                                   GtError *err);
 
+/* Do not output the header of the esq-file. This is needed
+   for generating testcases for Timo Beller. */
+
+void gt_encseq_encoder_disable_esq_header(GtEncseqEncoder *ee);
+
 /* The following type stores a two bit encoding in <tbe> with information
   about the number of two bit units which do not store a special
   character in <unitsnotspecial>. To allow the comparison of these
@@ -145,8 +150,8 @@ GtCodetype gt_encseq_extractprefixcode(unsigned int *unitsnotspecial,
                                        unsigned long frompos,
                                        unsigned int prefixlength);
 
-/* The following function compares two substrings beginning
-  at position <pos1>+<depth> and <pos2>+<depth> in <encseq>.
+/* The following function compares two substrings in <encseq1> and
+  <encseq2> beginning at position <pos1>+<depth> and <pos2>+<depth>, resp.
   <esr1> and <esr2> refer to memory areas for storeing a GtEncseqReader.
   The information about the length of the longest common prefix is stored
   in <commonunits>. <fwd> and <complement> specify if the sequence is
@@ -157,7 +162,8 @@ GtCodetype gt_encseq_extractprefixcode(unsigned int *unitsnotspecial,
   If <madepth> is 0, then the entire suffixes are compared. Otherwise, the
   comparison is restricted to the prefixes of length <maxdepth>. */
 int gt_encseq_compare_viatwobitencoding(GtCommonunits *commonunits,
-                                        const GtEncseq *encseq,
+                                        const GtEncseq *encseq1,
+                                        const GtEncseq *encseq2,
                                         GtReadmode readmode,
                                         GtEncseqReader *esr1,
                                         GtEncseqReader *esr2,
@@ -231,17 +237,29 @@ void gt_Viatwobitkeyvalues_reinit(GtViatwobitkeyvalues *vtk,
 /* The following is the destructor for the latter type */
 void gt_Viatwobitkeyvalues_delete(GtViatwobitkeyvalues *vtk);
 
-int gt_encseq_process_viatwobitencoding(GtCommonunits *commonunits,
-                                        const GtEncseq *encseq,
-                                        GtReadmode readmode,
-                                        unsigned long depth,
-                                        unsigned long maxdepth,
-                                        GtViatwobitkeyvalues *vtk1,
-                                        GtViatwobitkeyvalues *vtk2);
+/* The following function compare two substrings of the given encseqs
+   <encseq1> and <encseq2>
+   refered to via the <GtViatwobitkeyvalues>-parameters. The comparison
+   only works for sequences represented as a two bit encodings. It
+   starts with offset <depth> and stops at offset <maxdepth>, whenever
+   <maxdepth> is larger than 0. If <maxdepth> is 0, then the comparison
+   stops at the end of the sequence or at the first special character.
+   The encoded sequence is given via the parameter <encseq> and it is
+   accessed via the given <readmode> which also determines if the longest
+   common prefix is computed (whenever <GT_ISDIRREVERSE(readmode)> is false).
+*/
+int gt_encseq_twobitencoding_strcmp(GtCommonunits *commonunits,
+                                    const GtEncseq *encseq1,
+                                    const GtEncseq *encseq2,
+                                    GtReadmode readmode,
+                                    unsigned long depth,
+                                    unsigned long maxdepth,
+                                    GtViatwobitkeyvalues *vtk1,
+                                    GtViatwobitkeyvalues *vtk2);
 
-bool gt_has_twobitencoding(const GtEncseq *encseq);
+bool gt_encseq_has_twobitencoding(const GtEncseq *encseq);
 
-bool gt_has_twobitencoding_stoppos_support(const GtEncseq *encseq);
+bool gt_encseq_has_twobitencoding_stoppos_support(const GtEncseq *encseq);
 
 unsigned long gt_getnexttwobitencodingstoppos(bool fwd, GtEncseqReader *esr);
 
@@ -560,9 +578,6 @@ int gt_encseq_check_consistency(const GtEncseq *encseq,
 int gt_encseq_check_external_twobitencoding_to_file(const char *indexname,
                                                     GtError *err);
 
-/* the following function returns a count value */
-unsigned long countgt_encseq_compare_viatwobitencoding_get(void);
-
 uint64_t gt_encseq_pairbitsum(const GtEncseq *encseq);
 
 /* the following function checks if a sequence number and relative
@@ -579,4 +594,7 @@ void gt_encseq_relpos_seqnum_check(const char *filename,int line,
 #define GT_UNIQUEINT(POS)        ((unsigned long) ((POS) + GT_COMPAREOFFSET))
 #define GT_ISUNIQUEINT(POS)      ((POS) >= GT_COMPAREOFFSET)
 
+/* Reverse the range with respect to the given total length */
+void gt_range_reverse(unsigned long totallength,GtRange *range);
+
 #endif
