@@ -32,14 +32,7 @@ typedef struct GtOptionParser GtOptionParser;
    the descriptions to manually affect the formatting. */
 typedef struct GtOption GtOption;
 
-/* Possible option parser return values. <GT_OPTION_PARSER_OK> denotes that
-   everything went fine, <GT_OPTION_PARSER_ERROR> that an error occured during
-   option parsing, and <GT_OPTION_PARSER_REQUESTS_EXIT> that the option parser
-   requests an exit, because option <-help>, <-help+>, <-helpdev> or <-version>
-   was used. */
-typedef enum GtOPrval GtOPrval;
-
-enum GtOPrval{
+enum GtOPrval {
   GT_OPTION_PARSER_OK,           /* Everything went fine. */
   GT_OPTION_PARSER_ERROR,        /* An error occured during option parsing. */
   GT_OPTION_PARSER_REQUESTS_EXIT /* The option parser requests an exit, because
@@ -47,6 +40,13 @@ enum GtOPrval{
                                     was used. */
 };
 
+/* Possible option parser return values. <GT_OPTION_PARSER_OK> denotes that
+   everything went fine, <GT_OPTION_PARSER_ERROR> that an error occured during
+   option parsing, and <GT_OPTION_PARSER_REQUESTS_EXIT> that the option parser
+   requests an exit, because option <-help>, <-help+>, <-helpdev> or <-version>
+   was used. */
+typedef enum GtOPrval GtOPrval;
+
 typedef void (*GtShowVersionFunc)(const char *progname);
 typedef int  (*GtShowCommentFunc)(const char *progname, void *data, GtError*);
 typedef int  (*GtOptionParserHookFunc)(void *data, GtError*);
@@ -312,6 +312,12 @@ void            gt_option_is_mandatory_either(GtOption *option_a,
 void            gt_option_is_mandatory_either_3(GtOption *option_a,
                                                 const GtOption *option_b,
                                                 const GtOption *option_c);
+/* Make it mandatory, that one of the options <option_a>, <option_b>, <option_c>
+   or <option_d> is used. */
+void            gt_option_is_mandatory_either_4(GtOption *option_a,
+                                                const GtOption *option_b,
+                                                const GtOption *option_c,
+                                                const GtOption *option_d);
 /* Set that <option> is only shown in the output of <-help+>. */
 void            gt_option_is_extended_option(GtOption *option);
 /* Set that <option> is only shown in the output of <-helpdev>. */
@@ -322,6 +328,11 @@ void            gt_option_imply(GtOption *option_a, const GtOption *option_b);
 void            gt_option_imply_either_2(GtOption *option_a,
                                          const GtOption *option_b,
                                          const GtOption *option_c);
+/* Make <option_a> imply either <option_b>, <option_c> or <option_d> */
+void            gt_option_imply_either_3(GtOption *option_a,
+                                         const GtOption *option_b,
+                                         const GtOption *option_c,
+                                         const GtOption *option_d);
 /* Set that the options <option_a> and <option_b> exclude each other. */
 void            gt_option_exclude(GtOption *option_a, GtOption *option_b);
 /* Hide the default value of <option> in <-help> output. */
