@@ -15,17 +15,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef WITHOUT_CAIRO
 #include <string.h>
 #include "core/assert_api.h"
-#include "core/unused_api.h"
-#include "extended/anno_db_gfflike_api.h"
-#include "extended/anno_db_prepared_stmt.h"
-#include "extended/anno_db_schema_rep.h"
-#include "extended/rdb_visitor_rep.h"
-#include "annotationsketch/feature_index_rep.h"
-#include "annotationsketch/feature_index.h"
-#include "annotationsketch/feature_visitor.h"
+#include "core/class_alloc_lock.h"
 #include "core/cstr_api.h"
 #include "core/ensure.h"
 #include "core/fileutils_api.h"
@@ -36,19 +28,27 @@
 #include "core/ma.h"
 #include "core/range.h"
 #include "core/strand_api.h"
-#include "core/thread.h"
+#include "core/thread_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
 #include "core/fa.h"
+#include "core/unused_api.h"
 #include "core/xansi_api.h"
 #include "core/xposix.h"
-#include "extended/genome_node.h"
-#include "extended/gff3_in_stream.h"
+#include "extended/anno_db_gfflike_api.h"
+#include "extended/anno_db_prepared_stmt.h"
+#include "extended/anno_db_schema_rep.h"
+#include "extended/feature_index_rep.h"
+#include "extended/feature_index.h"
+#include "extended/feature_visitor.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_observer.h"
 #include "extended/feature_node_iterator_api.h"
+#include "extended/genome_node.h"
+#include "extended/gff3_in_stream.h"
 #include "extended/rdb_api.h"
 #include "extended/rdb_sqlite_api.h"
+#include "extended/rdb_visitor_rep.h"
 
 struct GtAnnoDBGFFlike {
   const GtAnnoDBSchema parent_instance;
@@ -1989,23 +1989,27 @@ GtFeatureIndex* anno_db_gfflike_build(GtAnnoDBSchema *schema, GtRDB *db,
 const GtAnnoDBSchemaClass* gt_anno_db_gfflike_class()
 {
   static const GtAnnoDBSchemaClass *adbsc = NULL;
+  gt_class_alloc_lock_enter();
   if (!adbsc) {
     adbsc = gt_anno_db_schema_class_new(sizeof (GtAnnoDBGFFlike),
                                         anno_db_gfflike_free,
                                         anno_db_gfflike_build);
   }
+  gt_class_alloc_lock_leave();
   return adbsc;
 }
 
 static const GtRDBVisitorClass* gfflike_setup_visitor_class()
 {
   static const GtRDBVisitorClass *svc = NULL;
+  gt_class_alloc_lock_enter();
   if (!svc) {
     svc = gt_rdb_visitor_class_new(sizeof (GtAnnoDBGFFlike),
                                    NULL,
                                    anno_db_gfflike_init_sqlite,
                                    anno_db_gfflike_init_mysql);
   }
+  gt_class_alloc_lock_leave();
   return svc;
 }
 
@@ -2033,7 +2037,9 @@ int gt_anno_db_gfflike_unit_test(GtError *err)
   GtError *testerr = NULL;
   GtAnnoDBSchema *adb = NULL;
   FILE *tmpfp;
+#ifdef HAVE_SQLITE
   GtRDB *rdb;
+#endif
   GtStr* tmpfilename;
   gt_error_check(err);
 
@@ -2043,6 +2049,7 @@ int gt_anno_db_gfflike_unit_test(GtError *err)
   tmpfp = gt_xtmpfp(tmpfilename);
   gt_fa_xfclose(tmpfp);
 
+#ifdef HAVE_SQLITE
   rdb = gt_rdb_sqlite_new(gt_str_get(tmpfilename), testerr);
   gt_ensure(had_err, rdb != NULL);
   if (!had_err) {
@@ -2054,6 +2061,7 @@ int gt_anno_db_gfflike_unit_test(GtError *err)
     fi = gt_anno_db_schema_get_feature_index(adb, rdb, testerr);
     gt_ensure(had_err, fi != NULL);
   }
+#endif
 
   if (!had_err) {
     /* run generic feature index tests */
@@ -2065,9 +2073,9 @@ int gt_anno_db_gfflike_unit_test(GtError *err)
   gt_str_delete(tmpfilename);
   gt_feature_index_delete(fi);
   gt_anno_db_schema_delete(adb);
+#ifdef HAVE_SQLITE
   gt_rdb_delete((GtRDB*) rdb);
+#endif
   gt_error_delete(testerr);
   return had_err;
 }
-
-#endif
