@@ -28,7 +28,7 @@
 #include "core/assert_api.h"
 #include "core/bittab_api.h"
 #include "core/cstr_api.h"
-#include "core/disc_distri.h"
+#include "core/disc_distri_api.h"
 #include "core/ensure.h"
 #include "core/fa.h"
 #include "core/fileutils_api.h"
@@ -45,7 +45,7 @@
 #include "extended/encdesc.h"
 #include "extended/encdesc_header_io.h"
 #include "extended/encdesc_rep.h"
-#include "extended/huffman.h"
+#include "extended/huffcode.h"
 #include "extended/rbtree.h"
 #include "extended/sampling.h"
 
@@ -1019,7 +1019,7 @@ int gt_encdesc_encoder_encode(GtEncdescEncoder *ee,
   bool is_not_at_pageborder;
   FILE *fp = NULL;
   GtStr *name1;
-  long pos,
+  long pos = 0,
        start_of_encoding,
        pagesize;
   unsigned long dummy = 0;
