@@ -1,6 +1,6 @@
 /*
-  Copyright (c) 2003-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
-  Copyright (c) 2003-2009 Center for Bioinformatics, University of Hamburg
+  Copyright (c) 2003-2013 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2003-2013 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -16,6 +16,7 @@
 */
 
 #include "gtt.h"
+#include "core/alphabet.h"
 #include "core/array.h"
 #include "core/array2dim_api.h"
 #include "core/array2dim_sparse.h"
@@ -25,23 +26,25 @@
 #include "core/bitpackstring.h"
 #include "core/bittab.h"
 #include "core/bsearch.h"
-#include "core/codon_iterator_encseq.h"
-#include "core/codon_iterator_simple.h"
+#include "core/codon_iterator_encseq_api.h"
+#include "core/codon_iterator_simple_api.h"
 #include "core/colorspace.h"
-#include "core/compactulongstore.h"
+#include "core/combinatorics.h"
+#include "core/compact_ulong_store.h"
 #include "core/countingsort.h"
 #include "core/cstr.h"
 #include "core/cstr_table.h"
 #include "core/desc_buffer.h"
-#include "core/disc_distri.h"
+#include "core/disc_distri_api.h"
 #include "core/dlist.h"
-#include "core/dynbittab.h"
+#include "core/dyn_bittab.h"
 #include "core/encseq.h"
 #include "core/grep_api.h"
 #include "core/hashmap.h"
 #include "core/hashtable.h"
 #include "core/interval_tree.h"
 #include "core/mathsupport.h"
+#include "core/md5_seqid.h"
 #include "core/quality.h"
 #include "core/queue.h"
 #include "core/sequence_buffer.h"
@@ -54,23 +57,27 @@
 #include "extended/elias_gamma.h"
 #include "extended/encdesc.h"
 #include "extended/evaluator.h"
+#include "extended/feature_index.h"
+#include "extended/feature_index_memory.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
 #include "extended/genome_node.h"
 #include "extended/gff3_escaping.h"
 #include "extended/golomb.h"
 #include "extended/hmm.h"
-#include "extended/huffman.h"
+#include "extended/huffcode.h"
 #include "extended/luaserialize.h"
+#include "extended/popcount_tab.h"
+#include "extended/ranked_list.h"
 #include "extended/rbtree.h"
 #include "extended/rmq.h"
 #include "extended/splicedseq.h"
 #include "extended/string_matching.h"
 #include "extended/tag_value_map.h"
 #include "extended/uint64hashtable.h"
+#include "ltr/gt_ltrclustering.h"
 #include "ltr/gt_ltrdigest.h"
 #include "ltr/gt_ltrharvest.h"
-#include "ltr/gt_ltrclustering.h"
 #include "ltr/ltrelement.h"
 #include "ltr/pbs.h"
 #include "ltr/ppt.h"
@@ -82,17 +89,19 @@
 #include "tools/gt_chain2dim.h"
 #include "tools/gt_chseqids.h"
 #include "tools/gt_clean.h"
+#include "tools/gt_compreads.h"
 #include "tools/gt_congruence.h"
 #include "tools/gt_convertseq.h"
 #include "tools/gt_csa.h"
-#include "tools/gt_compreads.h"
 #include "tools/gt_dev.h"
+#include "tools/gt_dot.h"
 #include "tools/gt_dupfeat.h"
 #include "tools/gt_encseq.h"
 #include "tools/gt_encseq2spm.h"
 #include "tools/gt_eval.h"
 #include "tools/gt_extractfeat.h"
 #include "tools/gt_extractseq.h"
+#include "tools/gt_featureindex.h"
 #include "tools/gt_fingerprint.h"
 #include "tools/gt_genomediff.h"
 #include "tools/gt_gff3.h"
@@ -109,13 +118,14 @@
 #include "tools/gt_merge.h"
 #include "tools/gt_mergefeat.h"
 #include "tools/gt_mgth.h"
+#include "tools/gt_mkfeatureindex.h"
 #include "tools/gt_mkfmindex.h"
 #include "tools/gt_mmapandread.h"
 #include "tools/gt_orffinder.h"
 #include "tools/gt_packedindex.h"
 #include "tools/gt_prebwt.h"
-#include "tools/gt_script_filter.h"
 #include "tools/gt_readjoiner.h"
+#include "tools/gt_script_filter.h"
 #include "tools/gt_select.h"
 #include "tools/gt_seq.h"
 #include "tools/gt_seqfilter.h"
@@ -129,6 +139,7 @@
 #include "tools/gt_shredder.h"
 #include "tools/gt_shulen.h"
 #include "tools/gt_simreads.h"
+#include "tools/gt_snpper.h"
 #include "tools/gt_splicesiteinfo.h"
 #include "tools/gt_splitfasta.h"
 #include "tools/gt_stat.h"
@@ -141,15 +152,11 @@
 #ifndef WITHOUT_CAIRO
 #include "annotationsketch/block.h"
 #include "annotationsketch/diagram.h"
-#include "annotationsketch/feature_index.h"
-#include "annotationsketch/feature_index_memory.h"
 #include "annotationsketch/gt_sketch.h"
 #include "annotationsketch/gt_sketch_page.h"
 #include "annotationsketch/image_info.h"
 #include "annotationsketch/rec_map.h"
 #include "annotationsketch/style.h"
-#include "tools/gt_mkfeatureindex.h"
-#include "tools/gt_featureindex.h"
 #include "annotationsketch/track.h"
 #endif
 
@@ -182,12 +189,14 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "compreads", gt_compreads());
   gt_toolbox_add_tool(tools, "congruence", gt_congruence());
   gt_toolbox_add_tool(tools, "csa", gt_csa());
+  gt_toolbox_add_tool(tools, "dot", gt_dot());
   gt_toolbox_add_tool(tools, "dupfeat", gt_dupfeat());
   gt_toolbox_add_tool(tools, "encseq", gt_encseq());
   gt_toolbox_add_tool(tools, "encseq2spm", gt_encseq2spm());
   gt_toolbox_add_tool(tools, "eval", gt_eval());
   gt_toolbox_add_tool(tools, "extractfeat", gt_extractfeat());
   gt_toolbox_add_tool(tools, "extractseq", gt_extractseq());
+  gt_toolbox_add_tool(tools, "featureindex", gt_featureindex());
   gt_toolbox_add_tool(tools, "fingerprint", gt_fingerprint());
   gt_toolbox_add_tool(tools, "genomediff", gt_genomediff());
   gt_toolbox_add_tool(tools, "gff3", gt_gff3());
@@ -203,6 +212,7 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "matchtool", gt_matchtool());
   gt_toolbox_add_tool(tools, "md5_to_id", gt_md5_to_id());
   gt_toolbox_add_tool(tools, "mergefeat", gt_mergefeat());
+  gt_toolbox_add_tool(tools, "mkfeatureindex", gt_mkfeatureindex());
   gt_toolbox_add_tool(tools, "packedindex", gt_packedindex());
   gt_toolbox_add_tool(tools, "prebwt", gt_prebwt());
   gt_toolbox_add_tool(tools, "readjoiner", gt_readjoiner());
@@ -220,6 +230,7 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "shredder", gt_shredder());
   gt_toolbox_add_tool(tools, "shulengthdist", gt_shulengthdist());
   gt_toolbox_add_tool(tools, "simreads", gt_simreads());
+  gt_toolbox_add_tool(tools, "snpper", gt_snpper());
   gt_toolbox_add_tool(tools, "splicesiteinfo", gt_splicesiteinfo());
   gt_toolbox_add_tool(tools, "splitfasta", gt_splitfasta());
   gt_toolbox_add_tool(tools, "stat", gt_stat());
@@ -228,8 +239,6 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "uniq", gt_uniq());
 #ifndef WITHOUT_CAIRO
   gt_toolbox_add(tools, "sketch", gt_sketch);
-  gt_toolbox_add_tool(tools, "featureindex", gt_featureindex());
-  gt_toolbox_add_tool(tools, "mkfeatureindex", gt_mkfeatureindex());
   gt_toolbox_add_tool(tools, "sketch_page", gt_sketch_page());
 #endif
   return tools;
@@ -242,8 +251,8 @@ GtHashmap* gtt_unit_tests(void)
   /* add unit tests */
 
   gt_hashmap_add(unit_tests, "compactulongstore class",
-                                              gt_GtCompactulongstore_unit_test);
-  gt_hashmap_add(unit_tests, "alignment class", gt_alignment_unit_test);
+                                              gt_compact_ulong_store_unit_test);
+  gt_hashmap_add(unit_tests, "alphabet class", gt_alphabet_unit_test);
   gt_hashmap_add(unit_tests, "alignment class", gt_alignment_unit_test);
   gt_hashmap_add(unit_tests, "array class", gt_array_unit_test);
   gt_hashmap_add(unit_tests, "array example", gt_array_example);
@@ -262,20 +271,23 @@ GtHashmap* gtt_unit_tests(void)
                                             gt_codon_iterator_simple_unit_test);
   gt_hashmap_add(unit_tests, "codon iterator class, encoded",
                                             gt_codon_iterator_encseq_unit_test);
+  gt_hashmap_add(unit_tests, "color space module", gt_colorspace_unit_test);
+  gt_hashmap_add(unit_tests, "combinatorics", gt_combinatorics_unit_test);
   gt_hashmap_add(unit_tests, "countingsort module", gt_countingsort_unit_test);
-  gt_hashmap_add(unit_tests, "cstr table class", gt_cstr_table_unit_test);
   gt_hashmap_add(unit_tests, "cstr module", gt_cstr_unit_test);
+  gt_hashmap_add(unit_tests, "cstr table class", gt_cstr_table_unit_test);
   gt_hashmap_add(unit_tests, "description buffer class",
                                                       gt_desc_buffer_unit_test);
   gt_hashmap_add(unit_tests, "disc distri class", gt_disc_distri_unit_test);
   gt_hashmap_add(unit_tests, "dlist class", gt_dlist_unit_test);
   gt_hashmap_add(unit_tests, "dlist example", gt_dlist_example);
-  gt_hashmap_add(unit_tests, "dynamic bittab class", gt_dynbittab_unit_test);
+  gt_hashmap_add(unit_tests, "dynamic bittab class", gt_dyn_bittab_unit_test);
   gt_hashmap_add(unit_tests, "elias gamma class", gt_elias_gamma_unit_test);
-  gt_hashmap_add(unit_tests, "evaluator class", gt_evaluator_unit_test);
   gt_hashmap_add(unit_tests, "encdesc class", gt_encdesc_unit_test);
   gt_hashmap_add(unit_tests, "encseq builder class",
                                                    gt_encseq_builder_unit_test);
+  gt_hashmap_add(unit_tests, "encseq gc module", gt_encseq_gc_unit_test);
+  gt_hashmap_add(unit_tests, "evaluator class", gt_evaluator_unit_test);
   gt_hashmap_add(unit_tests, "feature node iterator example",
                                              gt_feature_node_iterator_example);
   gt_hashmap_add(unit_tests, "feature node class", gt_feature_node_unit_test);
@@ -294,18 +306,22 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "ltrelement module", gt_ltrelement_unit_test);
   gt_hashmap_add(unit_tests, "mathsupport module", gt_mathsupport_unit_test);
   gt_hashmap_add(unit_tests, "memory allocator module", gt_ma_unit_test);
+  gt_hashmap_add(unit_tests, "MD5 seqid module", gt_md5_seqid_unit_test);
   gt_hashmap_add(unit_tests, "rdj: suffix-prefix matches list module",
                                                           gt_spmlist_unit_test);
-  gt_hashmap_add(unit_tests, "rdj: string graph class", gt_strgraph_unit_test);
-  gt_hashmap_add(unit_tests, "PPT finder module", gt_ppt_unit_test);
   gt_hashmap_add(unit_tests, "PBS finder module", gt_pbs_unit_test);
-  gt_hashmap_add(unit_tests, "queue class", gt_queue_unit_test);
+  gt_hashmap_add(unit_tests, "PPT finder module", gt_ppt_unit_test);
+  gt_hashmap_add(unit_tests, "popcount sorted tab", gt_popcount_tab_unit_test);
   gt_hashmap_add(unit_tests, "quality module", gt_quality_unit_test);
+  gt_hashmap_add(unit_tests, "queue class", gt_queue_unit_test);
   gt_hashmap_add(unit_tests, "range class", gt_range_unit_test);
+  gt_hashmap_add(unit_tests, "ranked list class", gt_ranked_list_unit_test);
   gt_hashmap_add(unit_tests, "red-black tree class", gt_rbtree_unit_test);
   gt_hashmap_add(unit_tests, "range minimum query class", gt_rmq_unit_test);
-  gt_hashmap_add(unit_tests, "safearith module", gt_safearith_unit_test);
+  gt_hashmap_add(unit_tests, "rdj: string graph class", gt_strgraph_unit_test);
+  gt_hashmap_add(unit_tests, "red-black tree class", gt_rbtree_unit_test);
   gt_hashmap_add(unit_tests, "safearith example", gt_safearith_example);
+  gt_hashmap_add(unit_tests, "safearith module", gt_safearith_unit_test);
   gt_hashmap_add(unit_tests, "sequence buffer class",
                                                   gt_sequence_buffer_unit_test);
   gt_hashmap_add(unit_tests, "splicedseq class", gt_splicedseq_unit_test);
@@ -318,8 +334,6 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "tag value map example", gt_tag_value_map_example);
   gt_hashmap_add(unit_tests, "tokenizer class", gt_tokenizer_unit_test);
   gt_hashmap_add(unit_tests, "translator class", gt_translator_unit_test);
-  gt_hashmap_add(unit_tests, "encseq gc module", gt_encseq_gc_unit_test);
-  gt_hashmap_add(unit_tests, "color space module", gt_colorspace_unit_test);
   gt_hashmap_add(unit_tests, "uint64hashtable", gt_uint64hashtable_unit_test);
 #ifndef WITHOUT_CAIRO
   gt_hashmap_add(unit_tests, "block class", gt_block_unit_test);
