@@ -17,6 +17,7 @@
 */
 
 #include "core/array.h"
+#include "core/class_alloc_lock.h"
 #include "core/cstr_api.h"
 #include "core/encseq.h"
 #include "core/hashmap.h"
@@ -29,6 +30,7 @@
 #include "extended/clustered_set_uf.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
+#include "extended/feature_type.h"
 #include "extended/node_stream_api.h"
 #include "extended/match.h"
 #include "extended/match_iterator_api.h"
@@ -308,7 +310,7 @@ static int cluster_annotate_nodes(GtClusteredSet *cs, GtEncseq *encseq,
   gt_error_check(err);
 
   if ((strcmp(feature, "lLTR") == 0) || (strcmp(feature, "rLTR") == 0))
-    real_feature = gt_cstr_dup("long_terminal_repeat");
+    real_feature = gt_cstr_dup(gt_ft_long_terminal_repeat);
   else
     real_feature = gt_cstr_dup(feature);
 
@@ -321,14 +323,14 @@ static int cluster_annotate_nodes(GtClusteredSet *cs, GtEncseq *encseq,
     while ((curnode = gt_feature_node_iterator_next(fni)) != NULL) {
       char header[BUFSIZ];
       fnt = gt_feature_node_get_type(curnode);
-      if (strcmp(fnt, "repeat_region") == 0) {
+      if (strcmp(fnt, gt_ft_repeat_region) == 0) {
         const char *rid;
         unsigned long id;
         seqid = gt_genome_node_get_seqid((GtGenomeNode*) curnode);
         rid = gt_feature_node_get_attribute(curnode, "ID");
         (void) sscanf(rid, "repeat_region%lu", &id);
         (void) snprintf(buffer, BUFSIZ, "%s_%lu", gt_str_get(seqid), id);
-      } else if (strcmp(fnt, "protein_match") == 0) {
+      } else if (strcmp(fnt, gt_ft_protein_match) == 0) {
         GtRange range;
         const char *attr;
         attr = gt_feature_node_get_attribute(curnode, "name");
@@ -546,10 +548,13 @@ static void gt_ltr_cluster_stream_free(GtNodeStream *ns)
 const GtNodeStreamClass* gt_ltr_cluster_stream_class(void)
 {
   static const GtNodeStreamClass *nsc;
-  if (!nsc)
+  gt_class_alloc_lock_enter();
+  if (!nsc) {
     nsc = gt_node_stream_class_new(sizeof(GtLTRClusterStream),
                                    gt_ltr_cluster_stream_free,
                                    gt_ltr_cluster_stream_next);
+  }
+  gt_class_alloc_lock_leave();
   return nsc;
 }
 
