@@ -21,6 +21,7 @@
 #endif
 #include <stdio.h>
 #include <string.h>
+#include "core/class_alloc_lock.h"
 #include "core/cstr_api.h"
 #include "core/fasta.h"
 #include "core/hashmap.h"
@@ -110,7 +111,7 @@ static int write_pdom(GtLTRFileOutStream *ls, GtArray *pdoms,
   }
 
   /* get amino acid sequence output file */
-  if (ls->write_pdom_alignments)
+  if (ls->write_pdom_aaseqs)
   {
     aafile = (GtFile*) gt_hashmap_get(ls->pdomaa_files, pdomname);
     if (aafile == NULL)
@@ -600,10 +601,13 @@ void gt_ltrfileout_stream_free(GtNodeStream *ns)
 const GtNodeStreamClass* gt_ltr_fileout_stream_class(void)
 {
   static const GtNodeStreamClass *nsc;
-  if (!nsc)
+  gt_class_alloc_lock_enter();
+  if (!nsc) {
     nsc = gt_node_stream_class_new(sizeof (GtLTRFileOutStream),
                                    gt_ltrfileout_stream_free,
                                    gt_ltrfileout_stream_next );
+  }
+  gt_class_alloc_lock_leave();
   return nsc;
 }
 
