@@ -16,7 +16,7 @@
 
 #include <string.h>
 #include "core/assert_api.h"
-#include "core/dataalign.h"
+#include "match/dataalign.h"
 #include "core/error.h"
 #include "core/log.h"
 #include "core/str.h"
