@@ -16,11 +16,11 @@
 */
 
 #include <math.h>
+#include "core/fa.h"
 #include "core/arraydef.h"
 #include "core/codetype.h"
 #include "core/encseq.h"
 #include "core/error_api.h"
-#include "core/fa.h"
 #include "core/logger_api.h"
 #include "core/mathsupport.h"
 #include "core/radix_sort.h"
@@ -31,7 +31,7 @@
 #include "core/unused_api.h"
 #include "core/minmax.h"
 #ifdef GT_THREADS_ENABLED
-#include "core/thread.h"
+#include "core/thread_api.h"
 #endif
 #include "firstcodes-buf.h"
 #include "firstcodes-spacelog.h"
