@@ -18,11 +18,16 @@
 #ifndef GREEDYEDIST_H
 #define GREEDYEDIST_H
 
-#include "core/types_api.h"
+#include "match/seqabstract.h"
 
-unsigned long greedyunitedist(const GtUchar *useq,
-                              unsigned long ulenvalue,
-                              const GtUchar *vseq,
-                              unsigned long vlenvalue);
+typedef struct GtFrontResource GtFrontResource;
+
+GtFrontResource *gt_frontresource_new(unsigned long maxdist);
+
+void gt_frontresource_delete(GtFrontResource *ftres);
+
+unsigned long greedyunitedist(GtFrontResource *ftres,
+                              const GtSeqabstract *useq,
+                              const GtSeqabstract *vseq);
 
 #endif
