@@ -19,7 +19,7 @@
 #include <inttypes.h>
 #include "core/array_api.h"
 #include "core/arraydef.h"
-#include "core/disc_distri.h"
+#include "core/disc_distri_api.h"
 #include "core/ensure.h"
 #include "core/fasta.h"
 #include "core/fileutils.h"
