@@ -16,7 +16,7 @@
 */
 
 #include "core/arraydef.h"
-#include "core/disc_distri.h"
+#include "core/disc_distri_api.h"
 #include "core/fa.h"
 #include "core/minmax.h"
 #include "core/unused_api.h"
