@@ -17,10 +17,10 @@
 
 #ifndef S_SPLINT_S
 #include <ctype.h>
+#include <zlib.h>
 #endif
 #include <stdlib.h>
 #include <string.h>
-#include <zlib.h>
 #include <stdbool.h>
 #include "core/assert_api.h"
 #include "core/chardef.h"
@@ -400,7 +400,7 @@ static void shiftrightwithchar(Kmerstream *spwp,GtUchar charcode)
 static void kmerstream_delete(Kmerstream *spwp)
 {
   gt_free(spwp->filltable);
-  gt_multimappowerfree(&spwp->multimappower);
+  gt_multimappower_delete(spwp->multimappower);
   specialwrapqueue(&spwp->spos);
   gt_free(spwp);
 }
