@@ -18,8 +18,21 @@
 #ifndef SFX_SAIN_H
 #define SFX_SAIN_H
 
+#include "core/timer_api.h"
+#include "core/logger_api.h"
 #include "core/encseq.h"
 
-void gt_sain_sortsuffixes(const GtEncseq *encseq,unsigned int sainmode);
+void gt_sain_encseq_sortsuffixes(const GtEncseq *encseq,
+                                 GtReadmode readmode,
+                                 bool intermediatecheck,
+                                 bool finalcheck,
+                                 GtLogger *logger,
+                                 GtTimer *timer);
+
+void gt_sain_plain_sortsuffixes(const GtUchar *plainseq,
+                                unsigned long len,
+                                bool intermediatecheck,
+                                GtLogger *logger,
+                                GtTimer *timer);
 
 #endif
