@@ -18,7 +18,7 @@
 #include "core/basename_api.h"
 #include "core/ma.h"
 #include "core/undef_api.h"
-#include "core/seqiterator_fastq.h"
+#include "core/seq_iterator_fastq_api.h"
 #include "core/unused_api.h"
 #include "extended/feature_type.h"
 #include "extended/gtdatahelp.h"
@@ -141,7 +141,7 @@ static GtOptionParser* gt_hop_option_parser_new(void *tool_arguments)
       "the corrected reads are output in the currect working directory "
       "in files which are named as the input files, each prepended "
       "by a prefix (see -outprefix option)\n"
-      "-reads allows to output the reads in the same order as in the input "
+      "-reads allows one to output the reads in the same order as in the input "
       "and is mandatory if the SAM contains more than a single primary "
       "alignment for each read (e.g. output of bwasw)\n"
       "see also -o option as an alternative",
@@ -476,10 +476,10 @@ static int gt_hop_runner(GT_UNUSED int argc, GT_UNUSED const char **argv,
               if (outfiles[i] == NULL)
                 had_err = -1;
               readset_iters[i] =
-                gt_seqiterator_fastq_new(infiles[i], err);
+                gt_seq_iterator_fastq_new(infiles[i], err);
               if (readset_iters[i] == NULL)
                 had_err = -1;
-              gt_seqiterator_fastq_relax_check_of_quality_description(
+              gt_seq_iterator_fastq_relax_check_of_quality_description(
                   (GtSeqIteratorFastQ*)readset_iters[i]);
               gt_free(bn);
             }
@@ -511,7 +511,7 @@ static int gt_hop_runner(GT_UNUSED int argc, GT_UNUSED const char **argv,
       gt_assert(readset_iters != NULL);
       gt_assert(outfiles != NULL);
       gt_str_array_delete(infiles[i]);
-      gt_seqiterator_delete(readset_iters[i]);
+      gt_seq_iterator_delete(readset_iters[i]);
       gt_file_delete(outfiles[i]);
     }
     gt_free(infiles);
