@@ -18,7 +18,7 @@
 #ifndef GT_MATCHTOOL_H
 #define GT_MATCHTOOL_H
 
-#include "core/tool.h"
+#include "core/tool_api.h"
 
 /* the matchtool tool */
 GtTool* gt_matchtool(void);
