@@ -28,12 +28,10 @@
 #include "core/showtime.h"
 #include "core/undef_api.h"
 #ifdef GT_THREADS_ENABLED
-#include "core/thread.h"
+#include "core/thread_api.h"
 #endif
 #include "core/warning_api.h"
-#ifndef S_SPLINT_S
 #include "core/xposix.h"
-#endif
 #include "tools/gt_seqcorrect.h"
 #include "match/reads2twobit.h"
 #include "match/rdj-contfinder.h"
