@@ -16,7 +16,7 @@
 */
 
 #include "core/str.h"
-#include "core/disc_distri.h"
+#include "core/disc_distri_api.h"
 #include "core/encseq.h"
 #include "core/fasta.h"
 #include "core/fa.h"
@@ -26,7 +26,7 @@
 #include "core/ma.h"
 #include "core/mathsupport.h"
 #include "core/option_api.h"
-#include "core/outputfile.h"
+#include "core/output_file_api.h"
 #include "core/progressbar.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
@@ -45,7 +45,7 @@ typedef struct {
 static void* gt_simreads_arguments_new(void)
 {
   GtSimreadsArguments *arguments = gt_calloc((size_t)1, sizeof *arguments);
-  arguments->ofi = gt_outputfileinfo_new();
+  arguments->ofi = gt_output_file_info_new();
   arguments->distlen_filename = gt_str_new();
   arguments->distlen_file = NULL;
   arguments->dsfilename = gt_str_new();
@@ -58,7 +58,7 @@ static void gt_simreads_arguments_delete(void *tool_arguments)
   GtSimreadsArguments *arguments = tool_arguments;
   if (!arguments) return;
   gt_file_delete(arguments->outfp);
-  gt_outputfileinfo_delete(arguments->ofi);
+  gt_output_file_info_delete(arguments->ofi);
   if (arguments->distlen_file != NULL)
     gt_fa_fclose(arguments->distlen_file);
   gt_str_delete(arguments->distlen_filename);
@@ -122,7 +122,7 @@ static GtOptionParser* gt_simreads_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, distlen_option);
 
   /* output file options */;
-  gt_outputfile_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
 
   /* -p */
   p_option = gt_option_new_bool("p", "show a progress bar",
